==> sword_1.5.3.orig.tar.gz: sword-1.5.3.orig/apps/windoze/CBuilder5/InstallMgr/StatusFrm.h <==
//---------------------------------------------------------------------------
#ifndef StatusFrmH
#define StatusFrmH
//---------------------------------------------------------------------------
#include <Classes.hpp>
#include <Controls.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <ExtCtrls.hpp>
#include <NMFtp.hpp>
#include "MainFrm.h"
#include "IdBaseComponent.hpp"
#include "IdComponent.hpp"
#include "IdFTP.hpp"
#include "IdTCPClient.hpp"
#include "IdTCPConnection.hpp"
//---------------------------------------------------------------------------
class TStatusForm : public TForm
{
__published:	// IDE-managed Components
	TPanel *Panel1;
	TPanel *Panel2;
	TButton *Button1;
	TPanel *statusBar;
	TPanel *Panel3;
	TPanel *actionBar;
	TIdFTP *ftpCon;
	void __fastcall FormShow(TObject *Sender);
	void __fastcall Cleanup(TObject *Sender);
	void __fastcall FormClose(TObject *Sender, TCloseAction &Action);
	void __fastcall Button1Click(TObject *Sender);
	void __fastcall ftpConWork(TObject *Sender, TWorkMode AWorkMode,
		const int AWorkCount);
private:	// User declarations
	class TFTPThread : public TThread {
		bool abort;
		InstallSourceTab *ist;
		string src;
		string dest;
		string buffer;
		string buffer2;
		string suffix;
		bool dirTransfer;
		bool passive;
	protected:
		void __fastcall Execute();
	public:
//		TNMFTP *FTPLink;
		__fastcall TFTPThread(InstallSourceTab *iist, const char *isrc, const char *idest, bool idirTransfer = false, bool CreateSuspended = false, bool ipassive = false, const char *suffix = "");
		__fastcall TFTPThread::~TFTPThread();
		void __fastcall FTPLinkPacketRecvd(TObject *Sender);
		void __fastcall CreateFTPObject(void);
		void __fastcall PreConnect(void);
		void __fastcall PreDownload1(void);
		void __fastcall PreDownload2(void);
//		void __fastcall Cleanup(void);
	} *ftpThread;
public:		// User declarations
	long currentByteCount;
	long currentFileSize;
	InstallSourceTab *ist;
	string src;
	string dest;
	string suffix;
	bool dirTransfer;
	bool passive;
	bool abort;
		void __fastcall UpdateBytes();
	__fastcall TStatusForm(TComponent* Owner);
};
//---------------------------------------------------------------------------
extern PACKAGE TStatusForm *StatusForm;
//---------------------------------------------------------------------------
#endif

==> sword-1.5.4.tar.gz: sword-1.5.4/apps/windoze/CBuilder5/InstallMgr/StatusFrm.h <==
//---------------------------------------------------------------------------
#ifndef StatusFrmH
#define StatusFrmH
//---------------------------------------------------------------------------
#include <Classes.hpp>
#include <Controls.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <ExtCtrls.hpp>
//#include <NMFtp.hpp>
#include "MainFrm.h"
#include <ComCtrls.hpp>
//#include "IdBaseComponent.hpp"
//#include "IdComponent.hpp"
//#include "IdFTP.hpp"
//#include "IdTCPClient.hpp"
//#include "IdTCPConnection.hpp"
//---------------------------------------------------------------------------

class TFTPCon {
public:
	string Host;
	string Username;
	string Password;
	bool Passive;
	string cwd;
	
};

class TStatusForm : public TForm
{
__published:	// IDE-managed Components
	TPanel *Panel1;
	TPanel *Panel2;
	TButton *Button1;
	TPanel *statusBar;
	TPanel *Panel3;
	TPanel *actionBar;
	TPanel *Panel4;
	TPanel *Panel5;
	TProgressBar *fileProgress;
	TProgressBar *totalProgress;
	void __fastcall FormShow(TObject *Sender);
	void __fastcall Cleanup(TObject *Sender);
	void __fastcall FormClose(TObject *Sender, TCloseAction &Action);
	void __fastcall Button1Click(TObject *Sender);
//	void __fastcall ftpConWork(TObject *Sender, TWorkMode AWorkMode,
//		const int AWorkCount);
private:	// User declarations
	class TFTPThread : public TThread {
		bool abort;
		InstallSourceTab *ist;
		string src;
		string dest;
		string buffer;
		string buffer2;
		string suffix;
		bool dirTransfer;
		bool passive;
	protected:
		void __fastcall Execute();
	public:
//		TNMFTP *FTPLink;
		__fastcall TFTPThread(InstallSourceTab *iist, const char *isrc, const char *idest, bool idirTransfer = false, bool CreateSuspended = false, bool ipassive = false, const char *suffix = "");
		__fastcall TFTPThread::~TFTPThread();
		void __fastcall FTPLinkPacketRecvd(TObject *Sender);
		void __fastcall CreateFTPObject(void);
		void __fastcall PreConnect(void);
		void __fastcall PreDownload1(void);
		void __fastcall PreDownload2(void);
//		void __fastcall Cleanup(void);
	} *ftpThread;
public:		// User declarations
	TFTPCon *ftpCon;
	long completedBytes;
	long totalBytes;
	InstallSourceTab *ist;
	string src;
	string dest;
	string suffix;
	bool dirTransfer;
	bool passive;
	bool abort;
		void __fastcall UpdateBytes();
	__fastcall TStatusForm(TComponent* Owner);
	__fastcall ~TStatusForm();
};
//---------------------------------------------------------------------------
extern PACKAGE TStatusForm *StatusForm;
//---------------------------------------------------------------------------
#endif
